@@ -172,6 +172,7 @@ from .resources.base import Resource
 from .resources.sqlite import AsyncSQLiteResource
 from .resources.browser import AsyncBrowserResource
 from .resources.mcp import AsyncMCPResource
+from .resources.api import AsyncAPIResource
 
 logger = logging.getLogger(__name__)
 
@@ -385,6 +386,29 @@ class AsyncEnv(EnvironmentBase):
     def browser(self, name: str = "cdp") -> AsyncBrowserResource:
         return self.instance.browser(name)
 
+    def api(self, name: str = "api") -> AsyncAPIResource:
+        """Get an API resource for making HTTP requests to the app's API.
+
+        Args:
+            name: Name for the API resource (default: "api")
+
+        Returns:
+            AsyncAPIResource for making HTTP requests
+        """
+        # Use urls.api if available, otherwise fall back to urls.root + "/raw"
+        if self.urls and self.urls.api:
+            base_url = self.urls.api
+        elif self.urls and self.urls.root:
+            base_url = f"{self.urls.root.rstrip('/')}/raw"
+        elif self._manager_url_override and self._manager_url_override != "local://":
+            # URL mode: strip /api/v1/env suffix to get root URL
+            base_url = self._manager_url_override.rstrip('/')
+            if base_url.endswith('/api/v1/env'):
+                base_url = base_url[:-len('/api/v1/env')]
+        else:
+            raise ValueError("No API URL configured for this environment")
+        return self.instance.api(name, base_url)
+
     @property
     def mcp(self) -> AsyncMCPResource:
         mcp_url = f"{self.urls.root}mcp"
